|Astropy| |PyPI| |Travis_Build| |Issues| |RTD| |License| |Coverage|

SDSS_Catl_Utils - Utilities for SDSS Catalogues
------------------------------------------------

Repository for handling the catalogues used in Calderon et al. (2018)
for the SDSS DR7 group galaxy catalogues.

License
-------

This project is Copyright (c) Victor Calderon and licensed under
the terms of the BSD 3-Clause license. This package is based upon
the `Astropy package template <https://github.com/astropy/package-template>`_
which is licensed under the BSD 3-clause licence. See the licenses folder for
more information.

.. |Astropy| image:: http://img.shields.io/badge/powered%20by-AstroPy-orange.svg?style=flat
    :target: http://www.astropy.org
    :alt: Powered by Astropy Badge

.. |Coverage| image:: https://coveralls.io/repos/github/vcalderon2009/sdss_catl_utils/badge.svg?branch=master
   :target: https://coveralls.io/github/vcalderon2009/sdss_catl_utils?branch=master
   :alt: Coveralls Status

.. |Release| image:: https://img.shields.io/github/release/vcalderon2009/sdss_catl_utils.svg
   :target: https://github.com/vcalderon2009/sdss_catl_utils/releases/latest
   :alt: Latest Release

.. |PyPI| image:: https://img.shields.io/pypi/v/sdss-catl-utils.svg
   :target: https://pypi.python.org/pypi/sdss-catl-utils
   :alt: PyPI Release

.. |Travis_Build| image:: https://travis-ci.org/vcalderon2009/sdss_catl_utils.svg?branch=master
   :target: https://travis-ci.org/vcalderon2009/sdss_catl_utils
   :alt: Build Status

.. |Issues| image:: https://img.shields.io/github/issues/vcalderon2009/sdss_catl_utils.svg
   :target: https://github.com/vcalderon2009/sdss_catl_utils/issues
   :alt: Open Issues

.. |RTD| image:: https://readthedocs.org/projects/sdss-catls-utils/badge/?version=latest
   :target: https://sdss-catls-utils.readthedocs.io/en/latest/?badge=latest
   :alt: Documentation Status

.. |License| image:: https://img.shields.io/badge/License-BSD%203--Clause-blue.svg
   :target: https://opensource.org/licenses/BSD-3-Clause
   :alt: Project License 
